@@ -1026,7 +1026,7 @@ def _pkginfo_from_file_thread(cache, file, callback):
                 except GLib.Error as e:
                     if e.code == GLib.KeyFileError.KEY_NOT_FOUND:
                         warn("Installer: flatpak - flatpakref file doesn't have a Branch key, maybe nightly or testing.")
-                        branch = None
+                        branch = "master"
 
                 remote_name = _get_remote_name_by_url(fp_sys, url)
 
@@ -1064,7 +1064,7 @@ def _pkginfo_from_file_thread(cache, file, callback):
                 try:
                     rpool = pools[remote.get_name()]
                 except KeyError:
-                    rpool = Pool(remote)
+                    rpool = appstream_pool.Pool(remote)
                     _process_remote(cache, rpool, fp_sys, remote, Flatpak.get_default_arch())
 
                 # Add the ref to the cache, so we can work with it like any other in mintinstall
